function tableout = importExcelData(workbookFile,sheetName,startRow,endRow)
%importExcelData Import data from a spreadsheet
%   importExcelData(FILE) reads data from the first worksheet in the Microsoft
%   Excel spreadsheet file named FILE and returns the data as a table.
%
%   importExcelData(FILE,SHEET) reads from the specified worksheet.
%
%  importExcelData(FILE,SHEET,STARTROW,ENDROW) reads from the specified
%   worksheet for the specified row interval(s). Specify STARTROW and
%   ENDROW as a pair of scalars or vectors of matching size for
%   dis-contiguous row intervals. To read to the end of the file specify an
%   ENDROW of inf.%
% Example:
%   importExcelData('SparkSweep1.xls','Sheet1',2,10);
%
%   See also XLSREAD.

% Auto-generated by MATLAB on 2013/10/29 10:09:49
% Copyright 2013 The MathWorks, Inc.

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 3
    startRow = 2;
    endRow = 10;
end

%% Import the data
data = [xlsread(workbookFile, sheetName, sprintf('A%d:A%d',startRow(1),endRow(1))),...
    xlsread(workbookFile, sheetName, sprintf('G%d:G%d',startRow(1),endRow(1))),...
    xlsread(workbookFile, sheetName, sprintf('U%d:U%d',startRow(1),endRow(1)))];
for block=2:length(startRow)
    tmpDataBlock = [xlsread(workbookFile, sheetName, sprintf('A%d:A%d',startRow(block),endRow(block))),...
        xlsread(workbookFile, sheetName, sprintf('G%d:G%d',startRow(block),endRow(block))),...
        xlsread(workbookFile, sheetName, sprintf('U%d:U%d',startRow(block),endRow(block)))];
    data = [data;tmpDataBlock]; %#ok<AGROW>
end

%% Create table
tableout = table;

%% Allocate imported array to column variable names
tableout.SPEED = data(:,1);
tableout.LOAD = data(:,2);
tableout.BSFC = data(:,3);
