function readData()
%% Automating File Import
% Our data is stored in several Excel files. 
% We repeat for all .xls files in the "Location". 

%% Method #1: 
% we read each file into a for loop. 
Location = [pwd,'\data'];
% Store the name of all .xls files as a vector D
D = dir([Location, '\*.xls']);
% Extract the file names
filenames = {D(:).name}.';
% Store the name of all .xls files as a vector D
D = dir([Location, '\*.xls']);
% Extract the file names
filenames = {D(:).name}.'; 
tic
for ii = length(D):-1:1   % Takes around 2 minutes to process all the files 
    fullname       = [Location '\' D(ii).name];
    [~, name, ~]   = fileparts(fullname); % Strips off ".xls" extension
    Engine         = importExcelData(fullname);         
    [val, index]   = min(Engine.BSFC);
    EngineMin      = Engine(index,:);
    EngineMin.Name = categorical({name}); % Add the name
    AllEngines(ii,:) = EngineMin; 
end
toc
%Filter data
% Let's remove the BSFC values that are not realistic (BSFC<0)
GoodEngines = AllEngines(AllEngines.BSFC > 0, :);
figure
[~, ax, ~] = plotmatrix([GoodEngines.SPEED,GoodEngines.LOAD,GoodEngines.BSFC]);
Names = GoodEngines.Properties.VariableNames;
for ii = 1:length(Names)-1
    xlabel(ax(end,ii),Names{ii})
    ylabel(ax(ii,1),Names{ii})
end

%% Method #2:
% we use |spreadsheetDatastore|
tic
dsEngine = ...
    spreadsheetDatastore('data','FileExtensions',{'.xls','.xlsm'});
dsEngine.ReadSize = 'file'; 
%
dsEngine.SelectedVariableNames = {'SPEED','LOAD','BSFC'};
%
ii = 1;
while hasdata(dsEngine)
    Engine           = read(dsEngine); 
    [val, index]     = min(Engine.BSFC);
    EngineMin        = Engine(index,:);
    [~,name]         = fileparts(dsEngine.Files{ii});
    EngineMin.Name   = categorical({name}); % Add the name
    AllEngines(ii,:) = EngineMin;
    ii = ii+1;
end
toc
% Filter data 
% Let's remove the BSFC values that are not realistic (BSFC<0)
GoodEngines = AllEngines(AllEngines.BSFC > 0, :);
figure
% Create a plotmatrix with filtered data 
[~, ax, ~] = plotmatrix([GoodEngines.SPEED,GoodEngines.LOAD,GoodEngines.BSFC]);
Names = GoodEngines.Properties.VariableNames;
for ii = 1:length(Names)-1
    xlabel(ax(end,ii),Names{ii})
    ylabel(ax(ii,1),Names{ii})
end

