function prob = runBirthdayVec(numTrials, groupSize)
% RUNBIRTHDAYVEC Runs a Monte Carlo simulation using the Birthday Paradox code
%    PROB = RUNBIRTHDAYVEC(NUMTRIALS, GROUPSIZE) Calls the birthday code
%    NUMTRIALS times to see if any birthdays match in a group of size
%    GROUPSIZE.  The return value is the probability that a match will be
%    found.
%
%    Example:
%    p = runBirthdayVec(1e5, 30)

% Preallocate some memory for the matches
matches = false(1, numTrials);

for trial = 1:numTrials
    % Run a simulation for a group
    matches(trial) = birthday(groupSize);
end

% Probability is the sum of matches divided by number of trials
prob = sum(matches)/numTrials;


function match = birthday(groupSize)
% BIRTHDAY Simulates a single trial of the Birthday Paradox

% Create a list with a random birthday for each member in the group
bdays = randi(365, groupSize, 1);

%% TODO: try a different algorithmic approach based on |sort| to solve the same problem
% Sort the birthdays
bdays = sort(bdays);

% Check if someone else in the group shares the same birthday
match =  any(diff(bdays) == 0);
