%% Bootstrap
% The bootstrap procedure involves choosing random samples with replacement 
% from a data set and analyzing each sample the same way. Sampling with 
% replacement means that each observation is selected separately at random 
% from the original dataset. So a particular data point from the original 
% data set could appear multiple times in a given bootstrap sample. 
% The number of elements in each bootstrap sample equals the number of 
% elements in the original data set. The range of sample estimates you obtain 
% enables you to establish the uncertainty of the quantity you are estimating.
% This example from Efron and Tibshirani compares Law School 
% Admission Test (LSAT) scores and subsequent law school grade point average 
% (GPA) for a sample of 15 law schools.

load lawdata
h = plot(lsat,gpa,'*');
text(lsat,gpa,num2str([1:numel(lsat)]'))
lsline
xlabel('Average LSAT for Entering Class')
ylabel('Average GPA for Entering Class')
grid on


%%
% The least-squares fit line indicates that higher LSAT scores go with 
% higher law school GPAs. But how certain is this conclusion? The plot 
% provides some intuition, but nothing quantitative.
% We can calculate the correlation coefficient of the variables using the 
% |corr| function.

rhohat = corr(lsat,gpa)
%%
% How accurate is the estimate |rhohat|? is it possible that the true 
% correlation, for the entire population of law schools, is zero, and that the
% points seem to ashow agreement because of random fluctations?
% Using the |bootstrp| function you can resample the lsat and gpa vectors 
% as many times as you like and consider the variation in the resulting 
% correlation coefficients.
% Here is an example.
tic,rhos10000 = bootstrp(50000,'corr',lsat,gpa);,toc
%%
%% Examples of Parallel Statistical Functions
%p = parpool('local',3);
opt = statset('UseParallel','always');
tic,rhos10000 = bootstrp(50000,'corr',lsat,gpa,'Options',opt);,toc
%delete(p)
